aboutsummaryrefslogtreecommitdiff
path: root/rpkid/rpki/sql.py
diff options
context:
space:
mode:
Diffstat (limited to 'rpkid/rpki/sql.py')
-rw-r--r--rpkid/rpki/sql.py4
1 files changed, 2 insertions, 2 deletions
diff --git a/rpkid/rpki/sql.py b/rpkid/rpki/sql.py
index fc8cc809..25c2c21e 100644
--- a/rpkid/rpki/sql.py
+++ b/rpkid/rpki/sql.py
@@ -120,9 +120,9 @@ class template(object):
index_column, index_column)
self.delete = "DELETE FROM %s WHERE %s = %%s" % (table_name, index_column)
-class sql_persistant(object):
+class sql_persistent(object):
"""
Mixin for persistant class that needs to be stored in SQL.
"""
## @var sql_in_db
@@ -120,9 +120,9 @@ class template(object):
"""
- Mixin for persistant class that needs to be stored in SQL.
+ Mixin for persistent class that needs to be stored in SQL.
"""
## @var sql_in_db